==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_bs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=bs
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Adresa vase stranice', # MODIF
	'form_pet_aucune_signature' => 'Nijedan potpis ne odgovara ovom kodu...', # MODIF
	'form_pet_confirmation' => 'Potvrdite vas potpis:',
	'form_pet_deja_signe' => 'Vec ste potpisali ovaj tekst.',
	'form_pet_envoi_mail_confirmation' => 'Upravo vam je poslan e-mail sa potvrdom. Trebate posjetiti web stranicu naznacenu u tom e-mailu, da bi ste ovjerili vas potpis.', # MODIF
	'form_pet_mail_confirmation' => 'Dobar dan',
	'form_pet_message_commentaire' => 'Da li zelite napisati poruku ili komentar?', # MODIF
	'form_pet_nom_site2' => 'Ime vase web stranice', # MODIF
	'form_pet_probleme_technique' => 'Tehnicki problem, potpisi su trenutno nedostupni.',
	'form_pet_signature_validee' => 'Vas potpis je vazeci. Hvala!',
	'form_pet_site_deja_enregistre' => 'Ova stranica je vec registrovana',
	'form_pet_url_invalide' => 'URL adresa koju ste naznacili nije vazeca.',
	'form_pet_votre_email' => 'Vasa e-mail adresa',
	'form_pet_votre_nom' => 'Vase ime ili pseudo', # MODIF
	'form_pet_votre_site' => 'Ako imate web stranicu, mozete je naznaciti ispod',

	// I
	'info_adresse_email' => 'E-MAIL ADRESA:',
	'info_site_web' => 'WEB STRANICA :',

	// L
	'lien_reponse_article' => 'Odgovori na clanak'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_bs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=bs
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Aktiviraj peticiju',
	'bouton_radio_pas_petition' => 'Bez peticije',
	'bouton_radio_petition_activee' => 'Peticija je aktivirana',
	'bouton_radio_supprimer_petition' => 'Izbrisi peticiju',

	// F
	'form_pet_adresse_site' => 'Adresa vase stranice', # MODIF
	'form_pet_aucune_signature' => 'Nijedan potpis ne odgovara ovom kodu...', # MODIF
	'form_pet_confirmation' => 'Potvrdite vas potpis:',
	'form_pet_deja_signe' => 'Vec ste potpisali ovaj tekst.',
	'form_pet_envoi_mail_confirmation' => 'Upravo vam je poslan e-mail sa potvrdom. Trebate posjetiti web stranicu naznacenu u tom e-mailu, da bi ste ovjerili vas potpis.', # MODIF
	'form_pet_mail_confirmation' => 'Dobar dan',
	'form_pet_message_commentaire' => 'Da li zelite napisati poruku ili komentar?', # MODIF
	'form_pet_nom_site2' => 'Ime vase web stranice', # MODIF
	'form_pet_probleme_technique' => 'Tehnicki problem, potpisi su trenutno nedostupni.',
	'form_pet_signature_validee' => 'Vas potpis je vazeci. Hvala!',
	'form_pet_site_deja_enregistre' => 'Ova stranica je vec registrovana',
	'form_pet_url_invalide' => 'URL adresa koju ste naznacili nije vazeca.',
	'form_pet_votre_email' => 'Vasa e-mail adresa',
	'form_pet_votre_nom' => 'Vase ime ili pseudo', # MODIF
	'form_pet_votre_site' => 'Ako imate web stranicu, mozete je naznaciti ispod',

	// I
	'info_adresse_email' => 'E-MAIL ADRESA:',
	'info_site_web' => 'WEB STRANICA :',

	// L
	'lien_reponse_article' => 'Odgovori na clanak'
);

?>
